__version__ = '0.5.2'


from .equation import Equation
from .equation_demo import *
from .fpcross import FPCross
from .fpcross_oup_diag import FPCrossOUPDiag
